#include "SPI.h"
#include "Adafruit_GFX.h"
#include "Adafruit_ILI9341.h"
#include "SoundPlayer.h" // Include the sound player header

// LCD Configurations
#define TFT_MISO 16
#define TFT_SCK 18
#define TFT_MOSI 19
#define TFT_DC 20
#define TFT_RESET 21
#define TFT_CS 17
#define pico_OUT 0
#define pico_IN 1

Adafruit_ILI9341 tft = Adafruit_ILI9341(TFT_CS, TFT_DC, TFT_MOSI, TFT_SCK, TFT_RESET, TFT_MISO);

unsigned long startTime;
unsigned long lastUpdate = 0; // To track the last update time for the countdown
bool meetingDisplayed = false; // Flag to track if the meeting reminder has already been displayed
bool noReminderDisplayed = false; // Flag to track if the "No Reminder" screen has already been displayed

void setup() {
  Serial.begin(9600);

  // Initialize LCD
  tft.begin();
  tft.setRotation(3);

  // Draw static content (name and class)
  drawStaticContent();

  // Initialize sound system
  initializeSound();

  // Start the timer
  startTime = millis();

  //to give signal to the main board that meeting alreart is on
  pinMode(pico_OUT, OUTPUT);
  digitalWrite(pico_OUT, LOW);
}

void loop() {
  unsigned long elapsedTime = millis() - startTime;

  if (elapsedTime < 60000) {
    // Show countdown timer (updates every second)
    if (millis() - lastUpdate >= 1000) {
      updateCountdown((60000 - elapsedTime) / 1000);
      lastUpdate = millis();
    }
    digitalWrite(pico_OUT, LOW);
  } else if (elapsedTime < 90000) {
    // Display meeting reminder only once
    if (!meetingDisplayed) {
      displayMeetingReminder();
      meetingDisplayed = true; // Set flag to prevent re-displaying
      digitalWrite(pico_OUT, HIGH);
    }
  } else {
    // Show "No Reminder" screen only once
    if (!noReminderDisplayed) {
      showNoReminder();
      noReminderDisplayed = true; // Set flag to prevent re-displaying
    }
    digitalWrite(pico_OUT, LOW);
  }
}

// Draw the static parts of the screen
void drawStaticContent() {
  tft.fillScreen(ILI9341_BLACK);

  // Display name
  tft.setTextColor(ILI9341_WHITE);
  tft.setTextSize(3);
  tft.setCursor(20, 20);
  tft.println("Laxman Kafle");

  // Display class name
  tft.setTextSize(1);
  tft.setCursor(20, 70);
  tft.println("How to Make (Almost) Anything");

  // Prepare countdown or reminder label (static part)
  tft.setTextSize(2);
  tft.setCursor(20, 120);
  tft.setTextColor(ILI9341_YELLOW);
  tft.print("Reminder: ");
}

// Update the countdown dynamically
void updateCountdown(int countdown) {
  // Clear the countdown area
  tft.fillRect(150, 120, 50, 20, ILI9341_BLACK);

  // Display countdown
  tft.setCursor(150, 120);
  tft.setTextColor(ILI9341_YELLOW);
  tft.setTextSize(2);
  tft.println(countdown);
}

// Display the meeting reminder (static)
void displayMeetingReminder() {
  tft.fillScreen(ILI9341_RED); // Set background to red
  tft.setTextColor(ILI9341_WHITE);
  tft.setTextSize(3);
  tft.setCursor(30, 80);
  tft.println("MEETING ALERT!");
  tft.setCursor(30, 150);
  tft.println("5 MINUTES LEFT!");

  // Play sound alert
  playSound();
}

// Show "No Reminder" after the meeting (static)
void showNoReminder() {
  tft.fillScreen(ILI9341_BLACK); // Clear the screen
  drawStaticContent();           // Redraw the static parts

  // Display "No Reminder" message
  tft.setTextColor(ILI9341_WHITE);
  tft.setTextSize(2);
  tft.setCursor(20, 150);
  tft.println("No Reminder");
}
